{ pkgs, ... }: {
  imports = [
    ./crypto.nix
    ./design.nix
    ./extrafonts.nix
    ./media.nix
    ./office.nix
    ./theme.nix
    ./syncthing.nix
    ./wayland.nix
    ./wofi.nix
  ];

  xdg = {
    enable = true;
    configFile."mimeapps.list".force = true;
    mimeApps = {
      enable = true;
      associations.added = {
        "application/zip" = [ "org.gnome.FileRoller.desktop" ];
        "application/csv" = [ "calc.desktop" ];
        "application/pdf" = [ "okularApplication_pdf.desktop" ];
        "x-scheme-handler/org-protocol" = [ "org-protocol.desktop" ];
      };
      defaultApplications = {
        "application/zip" = [ "org.gnome.FileRoller.desktop" ];
        "application/csv" = [ "calc.desktop" ];
        "application/pdf" = [ "okularApplication_pdf.desktop" ];
        "x-scheme-handler/org-protocol" = [ "org-protocol.desktop" ];
      };
    };
    userDirs = {
      enable = true;
      createDirectories = true;
    };
  };

  home.sessionVariables = {
    WEBKIT_DISABLE_COMPOSITING_MODE = "1";
    NIXOS_OZONE_WL = "1";
    TERMINAL = "alacritty";
    QT_QPA_PLATFORM = "wayland";
  };
  home.sessionPath =
    [ "\${XDG_BIN_HOME}" "\${HOME}/.cargo/bin" "$HOME/.npm-global/bin" ];

  fonts.fontconfig.enable = true;

  services.mako = {
    enable = true;
    backgroundColor = "#282a36";
    textColor = "#80FFEA";
    borderColor = "#9742b5";
    width = 400;
    height = 150;
    padding = "10,20";
    borderRadius = 8;
    borderSize = 1;
    margin = "20,20";
  };

  programs.alacritty = {
    enable = true;
    settings = {
      env.TERM = "xterm-256color";
      font = {
        size = 12;
        #draw_bold_text_with_bright_colors = true;
      };
      scrolling.multiplier = 5;
      selection.save_to_clipboard = true;
      colors = {
        primary = {
          background = "0x22212c";
          #foregound = "0xf8f8f2";
        };
        cursor = {
          text = "0x454158";
          cursor = "0xf8f8f2";
        };
        selection = {
          text = "0xf8f8f2";
          background = "0x454158";
        };
        normal = {
          black = "0x22212c";
          red = "0xff9580";
          green = "0x8aff80";
          yellow = "0xffff80";
          blue = "0x9580ff";
          magenta = "0xff80bf";
          cyan = "0x80ffea";
          white = "0xf8f8f2";
        };
        bright = {
          black = "0x22212c";
          red = "0xffaa99";
          green = "0xa2ff99";
          yellow = "0xffff99";
          blue = "0xaa99ff";
          magenta = "0xff99cc";
          cyan = "0x99ffee";
          white = "0xffffff";
        };
      };
    };
  };
  home.pointerCursor = {
    gtk.enable = true;
    package = pkgs.bibata-cursors;
    name = "Bibata-Modern-Ice";
    size = 20;
  };
  home.packages = with pkgs; [
    appimage-run
    anytype
    blueberry
    brave
    brightnessctl
    clipman
    distrobox
    eww
    gnome.file-roller
    gnome.seahorse
    gnome.sushi
    glib
    gsettings-desktop-schemas
    graphviz
    hyprpaper
    ksnip
    nwg-look
    pamixer
    pavucontrol
    libsForQt5.qtstyleplugins
    nyxt
    pcmanfm
    qt5ct
    qt6.qtwayland
    rustdesk
    socat
    unrar
    unzip
    usbutils
    v4l-utils
    remmina
    wl-clipboard
    wlogout
    wtype
    xdg-utils
    ydotool
    zip
  ];
}
